pub struct CacheId(pub u64);Expand description
Opaque identifier for a cacheable file object Drivers are responsible for returning a stable, globally unique id for the lifetime of the filesystem instance.
Tuple Fields
0: u64Implementations