PageCacheCapable

Trait PageCacheCapable 

pub trait PageCacheCapable {
    // Required method
    fn cache_id(&self) -> CacheId;
}
FileObjects that support the global page cache must implement this trait.

Implementors should compose the id from (filesystem identity, file identity). The concrete composition is left to the filesystem driver for now.

Required Methods

fn cache_id(&self) -> CacheId

Returns a stable CacheId for this file for the lifetime of the underlying filesystem instance.

Implementors