pub trait PageCacheCapable {
// Required method
fn cache_id(&self) -> CacheId;
}Expand description
FileObjects that support the global page cache must implement this trait.
Implementors should compose the id from (filesystem identity, file identity). The concrete composition is left to the filesystem driver for now.